#[non_exhaustive]pub struct BatchGetPreparedStatementInput {
pub prepared_statement_names: Option<Vec<String>>,
pub work_group: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prepared_statement_names: Option<Vec<String>>A list of prepared statement names to return.
work_group: Option<String>The name of the workgroup to which the prepared statements belong.
Implementations
Sourceimpl BatchGetPreparedStatementInput
impl BatchGetPreparedStatementInput
Sourcepub fn prepared_statement_names(&self) -> &[String]
pub fn prepared_statement_names(&self) -> &[String]
A list of prepared statement names to return.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .prepared_statement_names.is_none().
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The name of the workgroup to which the prepared statements belong.
Sourceimpl BatchGetPreparedStatementInput
impl BatchGetPreparedStatementInput
Sourcepub fn builder() -> BatchGetPreparedStatementInputBuilder
pub fn builder() -> BatchGetPreparedStatementInputBuilder
Creates a new builder-style object to manufacture BatchGetPreparedStatementInput.